# magicsandbox_streaming

Python streaming utilities for [Magic Sandbox](https://magicsandbox.ai).

## Getting Started

`pip install magicsandbox_streaming`

## Usage

See the [Magic Sandbox docs](https://magicsandbox.ai/?_app=magicsandbox.Docs#streaming-json) for example usage.
